# lasertram
[![PyPI version](https://badge.fury.io/py/lasertram.svg)](https://badge.fury.io/py/lasertram)

Welcome to the repository for `lasertram`, a package for the time resolved analysis for processing laser ablation inductively coupled plasma mass spectrometry (LA-ICP-MS) data. It is utilized heavily in the dashboard [LaserTRAM-DB](https://github.com/jlubbersgeo/laserTRAM-DB).

## Documentation

please see the [Documentation](https://jlubbersgeo.github.io/lasertram/) for more!

## Installation

```
pip install lasertram
```

## Contributing

If you have features you'd like to see please open an issue or consider contributing yourself! I'm always happy to have help.

-- Jordan
